export const TIP_COMPONENT_HTML: string = `
<div class="tip-wrapper tip-position" [style.width]='maxWidth'>
    <clr-tooltip [clrTooltipDirection]="'top-right'" [clrTooltipSize]="'lg'">
        <div class="tip-wrapper tip-block bar-block-high" [style.width]='tipWidth(5)'></div>
        <div class="tip-wrapper tip-block bar-block-medium" [style.width]='tipWidth(4)'></div>
        <div class="tip-wrapper tip-block bar-block-low" [style.width]='tipWidth(3)'></div>
        <div class="tip-wrapper tip-block bar-block-unknown" [style.width]='tipWidth(2)'></div>
        <div class="tip-wrapper tip-block bar-block-none" [style.width]='tipWidth(1)'></div>
        <clr-tooltip-content>
            <div>
                <span class="bar-tooltip-font bar-tooltip-font-title">{{tipTitle}}</span>
            </div>
            <div class="bar-summary bar-tooltip-fon">
                <div *ngIf="hasHigh" class="bar-summary-item">
                    <clr-icon shape="exclamation-circle" class="is-error" size="24"></clr-icon>
                    <span>{{highCount}} {{'VULNERABILITY.SEVERITY.HIGH' | translate }} {{ highSuffix | translate }}</span>
                </div>
                <div *ngIf="hasMedium" class="bar-summary-item">
                    <clr-icon *ngIf="hasMedium" shape="exclamation-triangle" class="is-warning" size="24"></clr-icon>
                    <span>{{mediumCount}} {{'VULNERABILITY.SEVERITY.MEDIUM' | translate }} {{ mediumSuffix | translate }}</span>
                </div>
                <div *ngIf="hasLow" class="bar-summary-item">
                    <clr-icon shape="info-circle" class="is-info" size="24"></clr-icon>
                    <span>{{lowCount}} {{'VULNERABILITY.SEVERITY.LOW' | translate }} {{ lowSuffix | translate }}</span>
                </div>
                <div *ngIf="hasUnknown" class="bar-summary-item">
                    <clr-icon shape="help" size="24"></clr-icon>
                    <span>{{unknownCount}} {{'VULNERABILITY.SEVERITY.UNKNOWN' | translate }} {{ unknownSuffix | translate }}</span>
                </div>
                <div *ngIf="hasNone" class="bar-summary-item">
                    <clr-icon shape="check-circle" class="is-success" size="24"></clr-icon>
                    <span>{{noneCount}} {{'VULNERABILITY.SEVERITY.NONE' | translate }} {{ noneSuffix | translate }}</span>
                </div>
            </div>
            <div>
                <span class="bar-scanning-time">{{'VULNERABILITY.CHART.SCANNING_TIME' | translate}} </span>
                <span>{{completeTimestamp | date}}</span>
            </div>
        </clr-tooltip-content>
    </clr-tooltip>
</div>
`;

export const GRID_COMPONENT_HTML: string = `
<div class="row">
  <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12" style="height: 24px;">  
    <div class="row flex-items-xs-right option-right">
      <div class="flex-xs-middle">
        <hbr-filter [withDivider]="true" filterPlaceholder="{{'VULNERABILITY.PLACEHOLDER' | translate}}" (filter)="filterVulnerabilities($event)"></hbr-filter>  
        <span class="refresh-btn" (click)="refresh()"><clr-icon shape="refresh"></clr-icon></span>
      </div>
    </div>
  </div>
  <div class="col-lg-12 col-md-12 col-sm-12 col-xs-12">
    <clr-datagrid>
        <clr-dg-column [clrDgField]="'id'">{{'VULNERABILITY.GRID.COLUMN_ID' | translate}}</clr-dg-column>
        <clr-dg-column [clrDgField]="'severity'">{{'VULNERABILITY.GRID.COLUMN_SEVERITY' | translate}}</clr-dg-column>
        <clr-dg-column [clrDgField]="'package'">{{'VULNERABILITY.GRID.COLUMN_PACKAGE' | translate}}</clr-dg-column>
        <clr-dg-column [clrDgField]="'version'">{{'VULNERABILITY.GRID.COLUMN_VERSION' | translate}} version</clr-dg-column>
        <clr-dg-column [clrDgField]="'fixedVersion'">{{'VULNERABILITY.GRID.COLUMN_FIXED' | translate}}</clr-dg-column>

        <clr-dg-placeholder>{{'VULNERABILITY.GRID.PLACEHOLDER' | translate}}</clr-dg-placeholder>
        <clr-dg-row *clrDgItems="let res of scanningResults">
            <clr-dg-cell>{{res.id}}</clr-dg-cell>
            <clr-dg-cell [ngSwitch]="res.severity">
              <span *ngSwitchCase="5" class="label label-danger">{{severityText(res.severity) | translate}}</span>
              <span *ngSwitchCase="4" class="label label-warning">{{severityText(res.severity) | translate}}</span>
              <span *ngSwitchCase="3" class="label label-success">{{severityText(res.severity) | translate}}</span>
              <span *ngSwitchCase="1" class="label label-info">{{severityText(res.severity) | translate}}</span>
              <span *ngSwitchDefault>{{severityText(res.severity) | translate}}</span>
            </clr-dg-cell>
            <clr-dg-cell>{{res.package}}</clr-dg-cell>
            <clr-dg-cell>{{res.version}}</clr-dg-cell>
            <clr-dg-cell>{{res.fixedVersion}}</clr-dg-cell>
            <clr-dg-row-detail *clrIfExpanded>
            {{'VULNERABILITY.GRID.COLUMN_DESCRIPTION' | translate}}: {{res.description}}
            </clr-dg-row-detail>
        </clr-dg-row>

        <clr-dg-footer>
            {{pagination.firstItem + 1}} - {{pagination.lastItem + 1}} {{'VULNERABILITY.GRID.FOOT_OF' | translate}} {{pagination.totalItems}} {{'VULNERABILITY.GRID.FOOT_ITEMS' | translate}}
            <clr-dg-pagination #pagination [clrDgPageSize]="25" [clrDgTotalItems]="scanningResults.length"></clr-dg-pagination>
        </clr-dg-footer>
    </clr-datagrid>
  </div>
</div>
`;

export const BAR_CHART_COMPONENT_HTML: string = `
<div class="bar-wrapper">
    <div *ngIf="pending" class="bar-state">
        <button class="btn btn-link scanning-button" (click)="scanNow()" [disabled]="scanningInProgress">{{'VULNERABILITY.STATE.PENDING' | translate}}</button>
    </div>
    <div *ngIf="queued" class="bar-state">
        <span>{{'VULNERABILITY.STATE.QUEUED' | translate}}</span>
    </div>
    <div *ngIf="error" class="bar-state">
        <clr-icon shape="info-circle" class="is-error" size="24"></clr-icon>
        <span style="margin-left:-5px;">{{'VULNERABILITY.STATE.ERROR' | translate}}</span>
    </div>
    <div *ngIf="scanning" class="bar-state">
        <div>{{'VULNERABILITY.STATE.SCANNING' | translate}}</div>
        <div class="progress loop" style="height:2px;min-height:2px;"><progress></progress></div>
    </div>
    <div *ngIf="completed" class="bar-state">
        <hbr-vulnerability-summary-chart [summary]="summary"></hbr-vulnerability-summary-chart>
    </div>
    <div *ngIf="unknown" class="bar-state">
        <clr-icon shape="warning" class="is-warning" size="24"></clr-icon>
        <span style="margin-left:-5px;">{{'VULNERABILITY.STATE.UNKNOWN' | translate}}</span>
    </div>
</div>
`;